"use strict";

/* global describe it */

const should = require('should');

const modems = require('../lib/modems');

describe('#modems', function() {
    
    describe('#getModemUrl', function() {

        const modemsConfig = {
            SMS0: {
                url: "http://localhost:8888/"
            }
        }
    
        it('should return correct url', function() {
            modems.getModemUrl('SMS0', modemsConfig).should.equal('http://localhost:8888/');
        })

        it ('should handle missing modems', function() {
            should.not.exists(modems.getModemUrl('SMS0', null));
            should.not.exists(modems.getModemUrl('SMS0', {}));
            should.not.exists(modems.getModemUrl('SMS1', modemsConfig));
        })
    })

    describe('#removeSuffixFromNumber', function() {
        const config = {
            number_suffix: '@phonenumber'
        }

        it('should return correct number', function() {
            modems.removeSuffixFromNumber('08181234@phonenumber', config).should.equal('08181234');
        })

        it ('should return correct number without suffix in the number', function() {
            modems.removeSuffixFromNumber('08181234', config).should.equal('08181234');
        })

        it ('should return correct number without suffix in config', function() {
            modems.removeSuffixFromNumber('08181234', null).should.equal('08181234');
            modems.removeSuffixFromNumber('08181234', {}).should.equal('08181234');
            modems.removeSuffixFromNumber('08181234@phonenumber', {}).should.equal('08181234');
        })
    })

})